from math import ceil
from PIL import Image, ImageDraw, ImageFont

def create_image_from_list(data, font_size=16, max_width=800):
    # 计算图片的宽度和高度
    full_text = ''.join([item[0] for item in data])
    font = ImageFont.truetype('/usr/local/share/fonts/ttf/dotfiles/MesloLGS/MesloLGS NF Regular.ttf', size=font_size)
    total_text_width = ceil(font.getlength(full_text))
    number_of_lines = (total_text_width // max_width) + 1 + 1 # one more line for \n of query
    text_width = max_width if total_text_width > max_width else total_text_width
    single_height = sum(abs(x) for x in font.getmetrics())
    text_height = (single_height + 10) * (number_of_lines + 1)
    image_width = text_width + 20
    image_height = text_height + 20

    # 创建一张新图片
    image = Image.new('RGB', (image_width, image_height), color='white')
    draw = ImageDraw.Draw(image)

    x = 10
    y = 10
    for word in data[0][0].split():
        word_width = font.getlength(word)
        if x + word_width > text_width:
            x = 10
            y += single_height + 5
        draw.text((x, y), word, font=font, fill='black')
        x += word_width + font.getlength(' ') 

    x = 10
    y += single_height + 5
    # 遍历列表中的元组
    for _, item in enumerate(data[1:]):
        text: str = item[0]  # 字符串
        color = 'blue' if item[1] == 0 else 'brown' if item[1] < 3 else 'red'
        for word in text.split():
            word_width = font.getlength(word)
            if x + word_width > text_width:
                x = 10
                y += single_height + 5
            draw.text((x, y), word, font=font, fill=color)
            x += word_width + font.getlength(' ')

    return image


if __name__ == "__main__":
    # 示例数据
    data = [("Start", -1), ('Hello', 2), ('World\n', 4), ('Python', 1)]

    data = data + data[1:] * 100

    # 创建图片
    image = create_image_from_list(data)

    # 保存图片
    image.save('output.png')
